@@ -73,7 +73,7 @@ async def RUN(configFile=None):
     print(tabulate(table, headers='keys', tablefmt='psql'))
 
 if __name__ == '__main__':
-    asyncio.run(RUN())
+    asyncio.run(RUN('testing/config.json'))
     print('Done')
 
 
