@@ -155,7 +155,7 @@ class wireless(object):
                                           self.NetworkWirelessSsid[i]):
                 # Make a copy of the master SSID.... overrides will be needed to write
                 temp_SSID = copy.deepcopy(master.NetworkWirelessSsid[i])
-                print(f'\t-{lib.bc.OKBLUE} SSID_Num[{i}] configuring '
+                print(f'\t-{lib.bc.WARNING} {netName} = {lib.bc.OKBLUE} SSID_Num[{i}] configuring '
                      f'SSID[{master.NetworkWirelessSsid[i]["name"]}] ')
 
                 ###  START OF THE OVERRIDES/EXCEPTIONS
