@@ -25,7 +25,7 @@ async def clone(network, master, appcfg, db, net_id, netName, product,oFunc):
 					configure = getattr(merakiFunction, f"update{task}")
 					try:
 						await configure(net_id, **masterSetting)
-						await  reSYNC(merakiFunction, net_id, network, task,
+						await  reSYNC(db, net_id, network, task,
 									  product,appcfg)
 					except AsyncAPIError as e:
 						print(
