@@ -15,8 +15,9 @@ async def reSYNC(_db: object, _net_id: str,network: object,task: str, product: s
        Nothing Updateds the network Object that is passed
     """
     try:
-        action = getattr(_db, f'get{task}')
-        setattr(network, task, await action(_net_id))
+        action = getattr(_db, product)
+        value = getattr(action,f'get{task}')
+        setattr(network, task, await value(_net_id))
     except AsyncAPIError as apie:
         print(
             f'\t {lib.bc.FAIL} Error Running Setting {task} '
